package org.framework.lazy.cloud.network.heartbeat.server.config;


import org.framework.lazy.cloud.network.heartbeat.server.netty.advanced.*;
import org.framework.lazy.cloud.network.heartbeat.server.standalone.application.LazyClientStatsChangeApplication;
import org.framework.lazy.cloud.network.heartbeat.server.standalone.application.LazyInternalNetworkPenetrationMappingApplication;
import org.framework.lazy.cloud.network.heartbeat.server.standalone.application.LazyNettyClientBlacklistApplication;
import org.framework.lazy.cloud.network.heartbeat.server.netty.advanced.*;

import org.springframework.beans.factory.config.BeanDefinition;
import org.springframework.context.annotation.Bean;
import org.springframework.context.annotation.Role;
import org.framework.lazy.cloud.network.heartbeat.common.adapter.ChannelFlowAdapter;


@Role(BeanDefinition.ROLE_INFRASTRUCTURE)
public class HeartbeatServerConfiguration {

    /**
     * 服务端 处理客户端心跳
     *
     * @return ServerHandleChannelHeartbeatTypeAdvanced
     */
    @Role(BeanDefinition.ROLE_INFRASTRUCTURE)
    @Bean
    public ServerHandleChannelHeartbeatTypeAdvanced serverChannelHeartbeatTypeAdvanced() {
        return new ServerHandleChannelHeartbeatTypeAdvanced();
    }

    /**
     * 处理 服务端处理客户端数据传输
     *
     * @return ServerHandleReportHandleChannelTransferTypeAdvanced
     */
    @Role(BeanDefinition.ROLE_INFRASTRUCTURE)
    @Bean
    public ServerHandleReportHandleChannelTransferTypeAdvanced serverReportChannelTransferTypeAdvanced(ChannelFlowAdapter channelFlowAdapter) {
        return new ServerHandleReportHandleChannelTransferTypeAdvanced(channelFlowAdapter);
    }

    @Role(BeanDefinition.ROLE_INFRASTRUCTURE)
    @Bean
    public ServerHandleClientConnectSuccessTypeAdvanced serverReportConnectSuccessTypeAdvanced(
            LazyClientStatsChangeApplication lazyClientStatsChangeApplication,
            LazyNettyClientBlacklistApplication lazyNettyClientBlacklistApplication,
            LazyInternalNetworkPenetrationMappingApplication lazyInternalNetworkPenetrationMappingApplication) {
        return new ServerHandleClientConnectSuccessTypeAdvanced(lazyClientStatsChangeApplication, lazyNettyClientBlacklistApplication, lazyInternalNetworkPenetrationMappingApplication);
    }

    /**
     * 服务端处理集群注册信息
     *
     * @param lazyNettyClusterNodeApplication 集群信息获取
     * @return ServerHandleReportClusterNodeRegisterTypeAdvanced
     */
    @Role(BeanDefinition.ROLE_INFRASTRUCTURE)
    @Bean
    public ServerHandleReportClusterNodeRegisterTypeAdvanced serverHandleReportClusterNodeRegisterTypeAdvanced() {
        return new ServerHandleReportClusterNodeRegisterTypeAdvanced();
    }

    @Role(BeanDefinition.ROLE_INFRASTRUCTURE)
    @Bean
    public ServerHandleReportDisconnectTypeAdvanced serverReportDisconnectTypeAdvanced(LazyClientStatsChangeApplication lazyClientStatsChangeApplication) {
        return new ServerHandleReportDisconnectTypeAdvanced(lazyClientStatsChangeApplication);
    }

    @Role(BeanDefinition.ROLE_INFRASTRUCTURE)
    @Bean
    public ServerHandleReportSingleClientCloseVisitorTypeAdvanced serverReportSingleClientCloseVisitorTypeAdvanced() {
        return new ServerHandleReportSingleClientCloseVisitorTypeAdvanced();
    }

    @Role(BeanDefinition.ROLE_INFRASTRUCTURE)
    @Bean
    public ServerHandleReportSingleClientRealConnectTypeAdvanced serverReportSingleClientRealConnectTypeAdvanced() {
        return new ServerHandleReportSingleClientRealConnectTypeAdvanced();
    }

    @Role(BeanDefinition.ROLE_INFRASTRUCTURE)
    @Bean
    public ServerHandleReportStagingClosedTypeAdvanced serverReportStagingClosedTypeAdvanced(LazyClientStatsChangeApplication lazyClientStatsChangeApplication) {
        return new ServerHandleReportStagingClosedTypeAdvanced(lazyClientStatsChangeApplication);
    }

    @Role(BeanDefinition.ROLE_INFRASTRUCTURE)
    @Bean
    public ServerHandleReportStagingOpenedTypeAdvanced serverReportStagingOpenedTypeAdvanced(LazyClientStatsChangeApplication lazyClientStatsChangeApplication) {
        return new ServerHandleReportStagingOpenedTypeAdvanced(lazyClientStatsChangeApplication);
    }


}
